<!-- <div align="center">
  <a href="https://warrior.js.org">
    <img alt="WarriorJS Banner" title="WarriorJS" src="logo/warriorjs-banner-dark.png?raw=true">
  </a>
</div> -->

<!-- <br /> -->

<div align="center">
  <strong>An exciting game of programming and Artificial Intelligence</strong>
</div>

<br />

<!-- <div align="center">
  <a href="https://circleci.com/gh/olistic/warriorjs">
    <img alt="CircleCI" src="https://img.shields.io/circleci/project/github/olistic/warriorjs/master.svg?style=flat-square">
  </a>
  <a href="https://codecov.io/gh/olistic/warriorjs">
    <img alt="Codecov" src="https://img.shields.io/codecov/c/github/olistic/warriorjs.svg?style=flat-square">
  </a>
  <a href="https://twitter.com/warrior_js">
    <img alt="Follow+WarriorJS+on+Twitter" src="https://img.shields.io/twitter/follow/warrior_js.svg?label=follow+warriorjs&style=flat-square">
  </a>
  <a href="https://spectrum.chat/warriorjs">
    <img alt="Join+WarriorJS+on+Spectrum" src="https://img.shields.io/badge/join_the_community-on_spectrum-7b16ff.svg?style=flat-square">
  </a>
</div>

<br /> -->

In WarriorPY, you wear the skin of a warrior climbing a tall tower to reach _The
Pythonic Sword_ at the top level. Legend has it that the sword bearer becomes
enlightened in the python language, but be warned: the journey will not be
easy. On each floor, you need to write Python to instruct the warrior to
battle enemies, rescue captives, and reach the stairs alive...

**No matter if you are new to programming or a Python guru, WarriorPY will
put your skills to the test. Will you dare?**

## Quick Start

1.  Install WarriorPY with [pip](https://pypi.org):

```sh
pip install @warriorpy/cli
```

2.  Launch the game:

```sh
warriorpy
```

3.  Create your warrior.

4.  You'll be pointed to a README file with instructions for the first level.

Good luck in your journey, warrior!

## Documentation

Learn how to play WarriorPY on the [official site](https://warriorpy.github.io)!

Jump straight to some of the most-visited pages:

- [**Set Up**](https://warriorpy.github.io/docs/set-up)
- [Gameplay](https://warriorpy.github.io/docs/gameplay)
- [Player API](https://warriorpy.github.io/docs/space-api)
- [CLI Options](https://warriorpy.github.io/docs/cli-options)

<!-- ## Preview

![WarriorJS Preview](https://user-images.githubusercontent.com/5600126/40150855-8b2acdd2-5952-11e8-9034-00dcee0c4c2c.gif)

> WarriorJS launched from the
> [Integrated Terminal](https://code.visualstudio.com/docs/editor/integrated-terminal)
> in [VS Code](https://code.visualstudio.com). To the left, `Player.js`, and to
> the right, a
> [Markdown Preview](https://code.visualstudio.com/docs/languages/markdown#_markdown-preview)
> of `README.md`. -->

## Contributing

We welcome contributions to WarriorJS! These are the many ways you can help:

- Submit patches and features
- Make [towers](https://warriorpy.github.io/docs/towers.html) (new levels for the
  game)
- Improve the [documentation and website](https://warriorpy.github.io)
- Report bugs
- Follow us on [Twitter](https://twitter.com/warrior_py)
<!-- - And [donate financially](https://opencollective.com/warriorpy)! -->

Please read our [contribution guide](CONTRIBUTING.md) to get started. Also note
that this project is released with a
[Contributor Code of Conduct](CODE_OF_CONDUCT.md), please make sure to review
and follow it.

## Contributors

Thanks goes to each one of our contributors! :pray:
[Become a contributor](CONTRIBUTING.md).

<!-- <a href="https://github.com/olistic/warriorjs/graphs/contributors"><img src="https://opencollective.com/warriorjs/contributors.svg?width=890&button=false" /></a> -->

<!-- ## Backers

Support us with a monthly donation and help us continue our activities!
[Become a backer](https://opencollective.com/warriorjs#backers).

<a href="https://opencollective.com/warriorjs#backers"><img src="https://opencollective.com/warriorjs/backers.svg?width=890" /></a> -->

<!-- ## Sponsors

Become a sponsor and get your logo here and on the
[official site](https://warrior.js.org)!
[Become a sponsor](https://opencollective.com/warriorjs#sponsors).

<a href="https://opencollective.com/warriorjs#sponsors"><img src="https://opencollective.com/warriorjs/sponsors.svg?width=890" /></a> -->

## Acknowledgments

This project was born as a port of
[ruby-warrior](https://github.com/ryanb/ruby-warrior). Credits for the original
idea go to [Ryan Bates](https://github.com/ryanb).

Most of the architechtural inspiration has been taken from the [WarriorJS project](https://github.com/olistic/warriorjs)

## License

WarriorPY is licensed under a [MIT License](LICENSE).
